==> geonkick_3.5.2.orig.tar.gz: geonkick-3.5.2/src/ExportAbstract.cpp <==
/**
 * File name: ExportAbstract.cpp
 * Project: Geonkick (A percussion synthesizer)
 *
 * Copyright (C) 2020 Iurie Nistor 
 *
 * This file is part of Geonkick.
 *
 * GeonKick is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "ExportAbstract.h"

ExportAbstract::ExportAbstract([[maybe_unused]] RkObject *parent,
                               const std::filesystem::path &path,
                               ExportFormat expFormat)
        : RkObject(nullptr)
        , exportFormat{expFormat}
        , exportPath{path}
        , exportProgress{0}
{
}

std::filesystem::path ExportAbstract::getExportPath() const
{
        return exportPath;
}
                
bool ExportAbstract::isError() const
{
        return exportError.empty();
}

std::string ExportAbstract::errorString() const
{
        return exportError;
}

ExportAbstract::ExportFormat ExportAbstract::format() const
{
        return exportFormat;
}

int ExportAbstract::progress() const
{
        return exportProgress;
}

void ExportAbstract::setProgress(const int val)
{
        exportProgress = val;
}

void ExportAbstract::setError(const std::string &error)
{
        exportError = error;
}

==> geonkick_3.7.0.orig.tar.gz: geonkick-3.7.0/src/ExportAbstract.cpp <==
/**
 * File name: ExportAbstract.cpp
 * Project: Geonkick (A percussive synthesizer)
 *
 * Copyright (C) 2020 Iurie Nistor
 *
 * This file is part of Geonkick.
 *
 * GeonKick is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "ExportAbstract.h"

ExportAbstract::ExportAbstract(const std::filesystem::path &path,
                               ExportFormat format)
        : exportFormat{format}
        , exportPath{path}
{
}

const std::filesystem::path& ExportAbstract::getExportPath() const
{
        return exportPath;
}

const ExportAbstract::ExportFormat& ExportAbstract::format() const
{
        return exportFormat;
}

void ExportAbstract::setError(const std::string_view &error)
{
        errorMessage = error;
}

const std::string& ExportAbstract::getError() const
{
        return errorMessage;
}


bool ExportAbstract::isError() const
{
        return !errorMessage.empty();
}
